// MCM_Test.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include <string.h>
#include <stdio.h>

#include "MCM_std.h"
#pragma comment(lib,"MCM_std.lib")

#ifndef _checkErr
#define _checkErr(fCall) if (error = (fCall), (error = (error < 0) ? error : VI_SUCCESS)) goto Error; else error = error
#endif

int _tmain(int argc, _TCHAR* argv[])
{
	ViStatus error = VI_SUCCESS;
	ViInt32 PortNum, CircuitNum, SmoothingType, ActionNum;
	ViChar* Path = new ViChar[256];
	ViChar* Prefix = new ViChar[16];

	_checkErr(MCM_init("TCPIP0::127.0.0.1::5025::SOCKET"));
	//_checkErr(MCM_init("TCPIP0::127.0.0.1::hislip0::INSTR"));
	_checkErr(MCM_ResetValues());

	_checkErr(MCM_SetActivePort(1));
	_checkErr(MCM_GetActivePort(&PortNum));
	printf("Selected Port: %d\n", PortNum);
	
	_checkErr(MCM_SetCircuit(MCM_ATTR_SeriesCShuntL));
	_checkErr(MCM_GetCircuit(&CircuitNum));
	switch(CircuitNum)
	{
	case  MCM_ATTR_SeriesLShuntC:	printf("Circuit: Series L - Shunt C\n"); break;
	case  MCM_ATTR_ShuntCSeriesL:	printf("Circuit: Shunt C - Series L\n"); break;
	case  MCM_ATTR_ShuntLSeriesC:	printf("Circuit: Shunt L - Series C\n"); break;
	case  MCM_ATTR_SeriesCShuntL:	printf("Circuit: Series C - Shunt L\n"); break;
	case  MCM_ATTR_ShuntLShuntC:	printf("Circuit: Shunt L - Shunt C\n"); break;
	case  MCM_ATTR_SeriesCShuntC:	printf("Circuit: Series C - Shunt C\n"); break;
	case  MCM_ATTR_ShuntCSeriesC:	printf("Circuit: Shunt C - Series C\n"); break;
	case  MCM_ATTR_SeriesLShuntL:	printf("Circuit: Series L - Shunt L\n"); break;
	case  MCM_ATTR_ShuntLSeriesL:	printf("Circuit: Shunt L - Series L\n"); break;
	}

	_checkErr(MCM_SetSmoothing(MCM_ATTR_E12/*MCM_ATTR_Smooth*/));
	_checkErr(MCM_GetSmoothing(&SmoothingType));
	switch(SmoothingType)
	{
	case MCM_ATTR_E6:		printf("Smoothing: E6\n"); break;
	case MCM_ATTR_E12:		printf("Smoothing: E12\n"); break;
	case MCM_ATTR_E24:		printf("Smoothing: E24\n"); break;
	case MCM_ATTR_Smooth:	printf("Smoothing: Smooth\n"); break;
	}	

	ViReal64 R = 51.31, L = 1.127e-9, C = 1.3014e-12, G = 19.22e-3;
	printf("Original data: R=%.4E L=%.4E C=%.4E G=%.4E\n", R, L, C, G);
	_checkErr(MCM_SetRLCGValues(R, L, C, G));
	_checkErr(MCM_GetRLCGValues(&R, &L, &C, &G));
	printf("Smoothed data: R=%.4E L=%.4E C=%.4E G=%.4E\n", R, L, C, G);

	_checkErr(MCM_SetAction(MCM_ATTR_Deembed));
	_checkErr(MCM_GetAction(&ActionNum));
	switch(ActionNum)
	{
	case MCM_ATTR_Embed:	printf("Action: Embedding\n"); break;
	case MCM_ATTR_Deembed:	printf("Action: Deembedding\n"); break;
	case MCM_ATTR_None:		printf("Action: None\n"); break;
	}	
		
	strncpy(Path, "C:\\VNA\\S2VNA", 256);
	_checkErr(MCM_SetS2PFilePath(Path));
	_checkErr(MCM_GetS2PFilePath(256, Path));
	printf("Touchstone File Path: %s\n", Path);

	strncpy(Prefix, "Antenna1_", 16);
	_checkErr(MCM_SetS2PFilePrefix(Prefix));
	_checkErr(MCM_GetS2PFilePrefix(16, Prefix));
	printf("File Prefix: %s\n", Prefix);

	ViBoolean Apply = 1;
	_checkErr(MCM_SetApplyImmediate(Apply));
	_checkErr(MCM_GetApplyImmediate(&Apply));
	printf("Apply Immediate: %s\n", (Apply == VI_TRUE)? "Yes" : "No");

	_checkErr(MCM_ApplyChanges());
		
Error:
	
	delete [] Prefix;
	delete [] Path;

	if (error != VI_SUCCESS) {
		//Error defined in visa.h and MCM_std.h
		printf("Error number: 0x%X\n", error);
	}

	MCM_close();

	printf("Press a Key to Exit\n");
	getchar();
	return 0;
}

